@@ -1,11 +1,11 @@
 package HTTP::Engine::Request;
-use Mouse;
+use Any::Moose;
 use HTTP::Headers::Fast;
 use HTTP::Engine::Types::Core qw( Uri Header );
 use URI::QueryParam;
 require Carp; # Carp->import is too heavy =(
 
-# Mouse role merging is borked with attributes
+# Mouse, Moose role merging is borked with attributes
 #with qw(HTTP::Engine::Request);
 
 # this object constructs all our lazy fields for us
@@ -357,7 +357,7 @@ sub parse {
     Carp::croak "The HTTP::Request method 'parse' is unsupported, use HTTP::Engine::RequestBuilder";
 }
 
-no Mouse;
+no Any::Moose;
 1;
 __END__
 
